==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/aa-ER/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'crwdns2044:0crwdne2044:0',
    'activated_disabled_help_text' => 'crwdns2045:0crwdne2045:0',
    'assets_user'       => 'crwdns1127:0crwdne1127:0',
    'bulk_update_warn'	=> 'crwdns1846:0crwdne1846:0',
    'bulk_update_help'	=> 'crwdns1847:0crwdne1847:0',
    'current_assets'    => 'crwdns1579:0crwdne1579:0',
    'clone'             => 'crwdns805:0crwdne805:0',
    'contact_user'      => 'crwdns1128:0crwdne1128:0',
    'edit'              => 'crwdns804:0crwdne804:0',
    'filetype_info'     => 'crwdns1391:0crwdne1391:0',
    'history_user'      => 'crwdns1129:0crwdne1129:0',
    'info'				=> 'crwdns1848:0crwdne1848:0',
    'restore_user'		=> 'crwdns1912:0crwdne1912:0',
    'last_login'        => 'crwdns1130:0crwdne1130:0',
    'ldap_config_text'  => 'crwdns1580:0crwdne1580:0',
    'print_assigned'    => 'crwdns1993:0crwdne1993:0',
    'email_assigned'    => 'crwdns10484:0crwdne10484:0',
    'user_notified'     => 'crwdns10486:0crwdne10486:0',
    'auto_assign_label' => 'crwdns11345:0crwdne11345:0',
    'auto_assign_help'  => 'crwdns11347:0crwdne11347:0',
    'software_user'     => 'crwdns1131:0crwdne1131:0',
    'send_email_help'   => 'crwdns5920:0crwdne5920:0',
    'view_user'         => 'crwdns1132:0crwdne1132:0',
    'usercsv'           => 'crwdns1193:0crwdne1193:0',
    'two_factor_admin_optin_help' => 'crwdns1823:0crwdne1823:0',
    'two_factor_enrolled' => 'crwdns6820:0crwdne6820:0',
    'two_factor_active'   => 'crwdns6822:0crwdne6822:0',
    'user_deactivated'  => 'crwdns6824:0crwdne6824:0',
    'user_activated'  => 'crwdns6826:0crwdne6826:0',
    'activation_status_warning' => 'crwdns6747:0crwdne6747:0',
    'group_memberships_helpblock' => 'crwdns6749:0crwdne6749:0',
    'superadmin_permission_warning' => 'crwdns6751:0crwdne6751:0',
    'admin_permission_warning' => 'crwdns6753:0crwdne6753:0',
    'remove_group_memberships' => 'crwdns6755:0crwdne6755:0',
    'warning_deletion_information' => 'crwdns10534:0crwdne10534:0',
    'update_user_assets_status' => 'crwdns10488:0crwdne10488:0',
    'checkin_user_properties' => 'crwdns6763:0crwdne6763:0',
    'remote_label'   => 'crwdns6828:0crwdne6828:0',
    'remote'   => 'crwdns6830:0crwdne6830:0',
    'remote_help' => 'crwdns6832:0crwdne6832:0',
    'not_remote_label' => 'crwdns6834:0crwdne6834:0',
    'vip_label' => 'crwdns11349:0crwdne11349:0',
    'vip_help' => 'crwdns11525:0crwdne11525:0',
    'create_user' => 'crwdns11353:0crwdne11353:0',
    'create_user_page_explanation' => 'crwdns11355:0crwdne11355:0',
    'email_credentials' => 'crwdns11357:0crwdne11357:0',
    'email_credentials_text' => 'crwdns11359:0crwdne11359:0',
    'next_save_user' => 'crwdns11361:0crwdne11361:0',
    'all_assigned_list_generation' => 'crwdns11415:0crwdne11415:0',
    'email_user_creds_on_create' => 'crwdns11517:0crwdne11517:0',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/aa-ER/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'crwdns2044:0crwdne2044:0',
    'activated_disabled_help_text' => 'crwdns2045:0crwdne2045:0',
    'assets_user'       => 'crwdns1127:0crwdne1127:0',
    'bulk_update_warn'	=> 'crwdns1846:0crwdne1846:0',
    'bulk_update_help'	=> 'crwdns1847:0crwdne1847:0',
    'current_assets'    => 'crwdns1579:0crwdne1579:0',
    'clone'             => 'crwdns805:0crwdne805:0',
    'contact_user'      => 'crwdns1128:0crwdne1128:0',
    'edit'              => 'crwdns804:0crwdne804:0',
    'filetype_info'     => 'crwdns1391:0crwdne1391:0',
    'history_user'      => 'crwdns1129:0crwdne1129:0',
    'info'				=> 'crwdns1848:0crwdne1848:0',
    'restore_user'		=> 'crwdns1912:0crwdne1912:0',
    'last_login'        => 'crwdns1130:0crwdne1130:0',
    'ldap_config_text'  => 'crwdns1580:0crwdne1580:0',
    'print_assigned'    => 'crwdns1993:0crwdne1993:0',
    'email_assigned'    => 'crwdns10484:0crwdne10484:0',
    'user_notified'     => 'crwdns10486:0crwdne10486:0',
    'users_notified'    => 'crwdns12921:0crwdne12921:0',
    'users_notified_warning' => 'crwdns12923:0crwdne12923:0',
    'auto_assign_label' => 'crwdns11345:0crwdne11345:0',
    'auto_assign_help'  => 'crwdns11347:0crwdne11347:0',
    'software_user'     => 'crwdns1131:0crwdne1131:0',
    'send_email_help'   => 'crwdns5920:0crwdne5920:0',
    'view_user'         => 'crwdns1132:0crwdne1132:0',
    'usercsv'           => 'crwdns1193:0crwdne1193:0',
    'two_factor_admin_optin_help' => 'crwdns1823:0crwdne1823:0',
    'two_factor_enrolled' => 'crwdns6820:0crwdne6820:0',
    'two_factor_active'   => 'crwdns6822:0crwdne6822:0',
    'user_deactivated'  => 'crwdns6824:0crwdne6824:0',
    'user_activated'  => 'crwdns6826:0crwdne6826:0',
    'activation_status_warning' => 'crwdns6747:0crwdne6747:0',
    'group_memberships_helpblock' => 'crwdns6749:0crwdne6749:0',
    'superadmin_permission_warning' => 'crwdns6751:0crwdne6751:0',
    'admin_permission_warning' => 'crwdns6753:0crwdne6753:0',
    'remove_group_memberships' => 'crwdns6755:0crwdne6755:0',
    'warning_deletion_information' => 'crwdns10534:0crwdne10534:0',
    'update_user_assets_status' => 'crwdns10488:0crwdne10488:0',
    'checkin_user_properties' => 'crwdns6763:0crwdne6763:0',
    'remote_label'   => 'crwdns6828:0crwdne6828:0',
    'remote'   => 'crwdns6830:0crwdne6830:0',
    'remote_help' => 'crwdns6832:0crwdne6832:0',
    'not_remote_label' => 'crwdns6834:0crwdne6834:0',
    'vip_label' => 'crwdns11349:0crwdne11349:0',
    'vip_help' => 'crwdns11525:0crwdne11525:0',
    'create_user' => 'crwdns11353:0crwdne11353:0',
    'create_user_page_explanation' => 'crwdns11355:0crwdne11355:0',
    'email_credentials' => 'crwdns11357:0crwdne11357:0',
    'email_credentials_text' => 'crwdns11359:0crwdne11359:0',
    'next_save_user' => 'crwdns11361:0crwdne11361:0',
    'all_assigned_list_generation' => 'crwdns11415:0crwdne11415:0',
    'email_user_creds_on_create' => 'crwdns11517:0crwdne11517:0',
];
